# Let's make some metals plots!!!

lakenames <- c("ERC","ERW", "HUK78","HU12", "MI41N","MIC51S", "ONE", "ONW", "SUIR","SULG", "SUW")
fulllakenames <- c("Erie Central", "Erie West", "Huron North", "Huron South", "Michigan North", "Michigan South", 
                   "Ontario East","Ontario West", "Superior Isle Royale","Superior East", "Superior West")
lakecolors <- c("darkolivegreen1", "chartreuse4", "yellow", "orange", "gray75", "gray 47", "indianred","red4", 
                "cyan","cornflowerblue","blue4")

datatypes = c(".ppm")
typenames = c("Sediment concentration (ppm)")


alldata = read.table("metals3.csv", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)
groups = read.table("metals groups for plotting2.csv", header=TRUE, sep=",",strip.white=TRUE)

row.names(alldata) = paste(alldata$Location,alldata$date)
alldata = alldata[ -c(1,2,4) ]    # delete columns
alldata[alldata < 0] <- 0

postscript("metals plots (3).ps",horizontal=TRUE,width=12,height=9,pointsize=12) #,paper="special")

for (pages in 1:max(groups$page)) {  # Step through groups to plot together      pages=1
  curvars = as.vector(groups[,1])[groups$page == pages]
  curtype = as.character(groups[groups$page == pages,]$type[1])  # oxide, alkali, etc.
  for (types in 1:length(datatypes)) {  # step through % and accum rate data types types=1
    reldata = cbind(alldata[,1,drop=F],alldata[,grep(datatypes[types],colnames(alldata))])
    colnames(reldata) = gsub(datatypes[types], "", colnames(reldata))
    reldata.group = cbind(reldata[,1,drop=F],reldata[,colnames(reldata) %in% curvars])
    taxaonly = reldata.group[,-1]
    taxa = names(reldata.group)[-1]  # taxon names vector (minus unwanted data)
    minforplots = c() ; maxforplots = c()
    for (n in 1:length(taxa)) {
      minforplots[n] = groups$minppm[which(groups$X == taxa[n])]
      maxforplots[n] = groups$maxppm[which(groups$X == taxa[n])]
      if (maxforplots[n] == 99999) { maxforplots[n] = max(reldata.group[taxa[n]],na.rm=T) }
    }
    maxvals = 0.9/length(taxa) # each as a fraction, cropping 0.05 off left and right
    
    par(mar=c(5,0,6.5,0))
    #par(mgp=c(2,0.2,0))
    par(oma=c(0,0,0,0))
    
    j=0.05 ; k=0.05 ; l=0.1 ; m=0.7  # set coords for first plot
    
    plot.new()
    for (x in 1:length(taxa)) {  # step through taxa  x=5
      k=k+maxvals
      par(fig=c(j,k,l,m), new=TRUE) # set location and make empty plot
      plot(reldata.group[[taxa[x]]],reldata.group$date,type="n",ylab="", yaxs='i', xaxs='i',
           xlim=c(minforplots[x],maxforplots[x]),ylim=(c(1850,2015)),axes=F, xlab="")
      for (y in 1:length(lakenames)) {      # step through lakes to plot lines  y=1
        curlake = reldata.group[grep(lakenames[y],row.names(reldata.group)),]
        lines(na.omit(curlake[[taxa[x]]]),curlake$date[!is.na(curlake[[taxa[x]]])], col=lakecolors[y],lwd=2)
        #     lines(curlake[[taxa[x]]],curlake$date, col=lakecolors[y],lwd=4) # leaves gaps for NAs
      }
      if (x == 1) { axis(2,labels=TRUE, padj=0.6) } # put dates at left
      if (x == length(taxa)) { axis(4,labels=TRUE,padj=-0.8) }  # put dates at right
      axis(1) #,at=ticlocs,labels=ticlabels,padj=-1.4,cex.axis=.7)
      box(lwd=2)
      axis(3,labels=taxa[x],at=((maxforplots[x]+minforplots[x])/2),padj=.5,las=1,ps=100,cex.axis=2)
      j=j+maxvals # move over for next plot
    }
    mtext(paste("Analyte type:",curtype," -- ",typenames[types]), side=3,line=10, adj=1, cex=1.2,col="black", outer=F)
    mtext(fulllakenames, side=3, line=c(9.3,8.6,7.9,7.2,6.5,5.8,5.1,4.4,3.7,3,2.3), adj=1, cex=1,col=lakecolors, outer=F)
  }
}
dev.off()

#end